@@ -254,4 +254,26 @@ test_that("libname() function works as expected with nested functions.", {
   expect_equal(res[["func2"]], c("iris", "beaver1")) 
 })
 
-
+test_that("libname() function works as expected with filter", {
+  
+  libname(dat, file.path( base_path, "SDTM"), 
+          engine = "sas7bdat", filter = c("ae", "dm", "lb", "vs"))
+  
+  d <- lib_info(dat)[["Name"]]
+  
+  expect_equal(d, c("ae", "dm", "lb", "vs"))
+  
+  libname(dat, file.path( base_path, "SDTM"), 
+          engine = "sas7bdat", filter = c("*e"))
+  
+  d <- lib_info(dat)[["Name"]]
+  
+  expect_equal(d, c("ae", "ie", "pe")) 
+  
+  libname(dat, file.path( base_path, "SDTM"), 
+          engine = "sas7bdat", filter = c("d*", "ex", "qs"))
+  
+  d <- lib_info(dat)[["Name"]]
+  
+  expect_equal(all(d %in% c("da", "dm", "ds", "ds_ihor", "ex", "qs")), TRUE) 
+})
